@@ -11,13 +11,17 @@
 
 #include <QObject>
 
-#include <Collection>
+#include <Akonadi/Collection>
+
+#include <memory>
 
 class QItemSelection;
 class QItemSelectionModel;
 
 namespace CalendarSupport
 {
+class CollectionSelectionPrivate;
+
 class CALENDARSUPPORT_EXPORT CollectionSelection : public QObject
 {
     Q_OBJECT
@@ -40,8 +44,8 @@ Q_SIGNALS:
 
 private:
     void slotSelectionChanged(const QItemSelection &, const QItemSelection &);
-    class Private;
-    Private *const d;
+
+    std::unique_ptr<CollectionSelectionPrivate> const d;
 };
 }
 
