@@ -3,16 +3,19 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef CALENDARSUPPORT_KCALPREFS_H
-#define CALENDARSUPPORT_KCALPREFS_H
+#pragma once
 
 #include "calendarsupport_export.h"
 #include "kcalprefs_base.h"
 
-#include <Collection>
+#include <Akonadi/Collection>
+
+#include <memory>
 
 namespace CalendarSupport
 {
+class KCalPrefsPrivate;
+
 class CALENDARSUPPORT_EXPORT KCalPrefs : public KCalPrefsBase
 {
     Q_OBJECT
@@ -60,9 +63,7 @@ public:
     QDateTime dayBegins() const;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<KCalPrefsPrivate> const d;
 };
 }
 
-#endif
